Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/fram_i2c_simpletest.py
    :caption: examples/fram_i2c_simpletest.py
    :linenos:

.. literalinclude:: ../examples/fram_spi_simpletest.py
    :caption: examples/fram_spi_simpletest.py
    :linenos:
